@@ -3,7 +3,7 @@ use 5.008005;
 use strict;
 use warnings;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 1;
 __END__
@@ -224,5 +224,9 @@ it under the same terms as Perl itself.
 
 tokuhirom E<lt>tokuhirom@gmail.comE<gt>
 
+=head1 CONTRIBUTORS
+
+magai
+
 =cut
 
